==> 1.0.1.tar.gz: bin/Indexer/JsonData/IndexerParameters.dart <==
import 'dart:io';

class IndexerParameters {

  //MUST BE GIVEN TO THE PROGRAM: The path that the indexer shall look for
  String pathToIndex = '';
  //MUST BE GIVEN TO THE PROGRAM: The path that the index shall write the files in
  String finalPath = '';
  //MUST BE GIVEN TO THE PROGRAM: The parameter to know if the program will print debug or not, true = debug, false = no debug
  bool verbose = true;
  //FOUND BY THE PROGRAM: The flutter path that was found by the Indexer
  String flutterPath = '';
  //FOUND BY THE PROGRAM: The pathToIndex, with a path separator at the end of it
  String uselessPath = '';


  String getFlutterPath() {
    final env = Platform.environment['PATH']?.split(';') ?? [];
    final realPath = Platform.pathSeparator +
        'packages' +
        Platform.pathSeparator +
        'flutter' +
        Platform.pathSeparator +
        'lib';
    var flutterPath = '';

    if (env.isEmpty) {
      return 'not found';
    }

    env.forEach((element) {
      if (element.contains('flutter' + Platform.pathSeparator + 'bin')) {
        flutterPath =
            element.replaceFirst(Platform.pathSeparator + 'bin', realPath);
      }
    });
    return (flutterPath);
  }

  String handlePath(String path) {
    if (path == 'FLUTTER_PATH') {
      return (flutterPath);
    }
    return (path);
  }

  void handleIndexerParameters(dynamic parameters) {
    List<String> tmp;

    flutterPath = getFlutterPath();
    pathToIndex = handlePath(parameters['pathToIndex']);
    tmp = parameters['pathToIndex'].split('\\');
    tmp.removeAt(tmp.length - 1);
    uselessPath = tmp.reduce((value, element) => value + '\\' + element) + '\\';
    verbose = parameters['verbose'];
    finalPath = parameters['finalPath'];
  }

  IndexerParameters(dynamic parameters) {
    handleIndexerParameters(parameters);
  }

}

==> 1.0.3.tar.gz: bin/Indexer/JsonData/IndexerParameters.dart <==
import 'dart:io';

class IndexerParameters {

  //MUST BE GIVEN TO THE PROGRAM: The path that the indexer shall look for
  String pathToIndex = '';
  //MUST BE GIVEN TO THE PROGRAM: The path that the index shall write the files in
  String finalPath = '';
  //MUST BE GIVEN TO THE PROGRAM: The parameter to know if the program will print debug or not, true = debug, false = no debug
  bool verbose = true;
  //FOUND BY THE PROGRAM: The flutter path that was found by the Indexer
  String flutterPath = '';
  //FOUND BY THE PROGRAM: The pathToIndex, with a path separator at the end of it
  String uselessPath = '';


  String getFlutterPath() {
    final env = Platform.environment['PATH']?.split(';') ?? [];
    final realPath = Platform.pathSeparator +
        'packages' +
        Platform.pathSeparator +
        'flutter' +
        Platform.pathSeparator +
        'lib';
    var flutterPath = '';

    if (env.isEmpty) {
      return 'not found';
    }

    env.forEach((element) {
      if (element.contains('flutter' + Platform.pathSeparator + 'bin')) {
        flutterPath =
            element.replaceFirst(Platform.pathSeparator + 'bin', realPath);
      }
    });
    return (flutterPath);
  }

  String handlePath(String path) {
    if (path == 'FLUTTER_PATH') {
      return (flutterPath);
    }
    return (path);
  }

  void handleIndexerParameters(dynamic parameters) {
    List<String> tmp;

    flutterPath = getFlutterPath();
    pathToIndex = handlePath(parameters['pathToIndex']);
    tmp = parameters['pathToIndex'].split(Platform.pathSeparator);
    tmp.removeAt(tmp.length - 1);
    uselessPath = tmp.reduce((value, element) => value + Platform.pathSeparator + element) + Platform.pathSeparator;
    verbose = parameters['verbose'];
    finalPath = parameters['finalPath'];
  }

  IndexerParameters(dynamic parameters) {
    handleIndexerParameters(parameters);
  }

}
